@@ -50,7 +50,7 @@ def test_diff_total_misses():
         'dummy/dummy3': 2,
     }
 
-    assert differ.diff_total_misses() == -4
+    assert differ.diff_total_misses() == 1
 
 
 def test_diff_total_misses_by_class():
@@ -79,7 +79,7 @@ def test_diff_line_rate():
     cobertura2 = make_cobertura('tests/dummy.source2/coverage.xml')
     differ = CoberturaDiff(cobertura1, cobertura2)
 
-    assert differ.diff_line_rate() == 0.31059999999999993
+    assert differ.diff_line_rate() == 0.15000000000000002
 
 
 def test_diff_line_rate_by_class():
